[前][次][番号順一覧][スレッド一覧]

ruby-changes:11653

From: akr <ko1@a...>
Date: Sun, 26 Apr 2009 20:18:15 +0900 (JST)
Subject: [ruby-changes:11653] Ruby:r23291 (trunk): * lib/rake.rb: use RbConfig::CONFIG instead of Config::CONFIG.

akr	2009-04-26 20:18:00 +0900 (Sun, 26 Apr 2009)

  New Revision: 23291

  http://svn.ruby-lang.org/cgi-bin/viewvc.cgi?view=rev&revision=23291

  Log:
    * lib/rake.rb: use RbConfig::CONFIG instead of Config::CONFIG.
    * lib/rbconfig/datadir.rb: ditto.

  Modified files:
    trunk/ChangeLog
    trunk/lib/rake.rb
    trunk/lib/rbconfig/datadir.rb

Index: ChangeLog
===================================================================
--- ChangeLog	(revision 23290)
+++ ChangeLog	(revision 23291)
@@ -1,3 +1,9 @@
+Sun Apr 26 20:17:24 2009  Tanaka Akira  <akr@f...>
+
+	* lib/rake.rb: use RbConfig::CONFIG instead of Config::CONFIG.
+
+	* lib/rbconfig/datadir.rb: ditto.
+
 Sun Apr 26 19:30:29 2009  Tanaka Akira  <akr@f...>
 
 	* time.c (time_arg): unused variable removed.
Index: lib/rake.rb
===================================================================
--- lib/rake.rb	(revision 23290)
+++ lib/rake.rb	(revision 23291)
@@ -932,7 +932,7 @@
 # added to the FileUtils utility functions.
 #
 module FileUtils
-  RUBY = File.join(Config::CONFIG['bindir'], Config::CONFIG['ruby_install_name']).
+  RUBY = File.join(RbConfig::CONFIG['bindir'], RbConfig::CONFIG['ruby_install_name']).
     sub(/.*\s.*/m, '"\&"')
 
   OPT_TABLE['sh']  = %w(noop verbose)

Index: lib/rbconfig/datadir.rb
===================================================================
--- lib/rbconfig/datadir.rb	(revision 23290)
+++ lib/rbconfig/datadir.rb	(revision 23291)
@@ -5,17 +5,17 @@
 #++
 
 
-module Config
+module RbConfig
 
   # Only define datadir if it doesn't already exist.
-  unless Config.respond_to?(:datadir)
+  unless RbConfig.respond_to?(:datadir)
 
     # Return the path to the data directory associated with the given
     # package name.  Normally this is just
     # "#{Config::CONFIG['datadir']}/#{package_name}", but may be
     # modified by packages like RubyGems to handle versioned data
     # directories.
-    def Config.datadir(package_name)
+    def RbConfig.datadir(package_name)
       File.join(CONFIG['datadir'], package_name)
     end
 
@@ -5,17 +5,17 @@
     # Return the path to the data directory associated with the given
     # package name.  Normally this is just
-    # "#{Config::CONFIG['datadir']}/#{package_name}", but may be
+    # "#{RbConfig::CONFIG['datadir']}/#{package_name}", but may be
     # modified by packages like RubyGems to handle versioned data
     # directories.
--
ML: ruby-changes@q...
Info: http://www.atdot.net/~ko1/quickml/

[前][次][番号順一覧][スレッド一覧]